@@ -15,8 +15,7 @@ use Catalyst::Runtime 5.80;
 
 use parent qw/Catalyst/;
 use Catalyst qw/-Debug
-                ConfigLoader
-                Static::Simple/;
+                ConfigLoader/;
 our $VERSION = '0.01';
 
 # Configure the application.
